@@ -1,9 +1,12 @@
 package Media::Info::Mplayer;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.04'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use Capture::Tiny qw(capture);
 use Log::Any::For::Builtins qw(system);
@@ -15,13 +18,11 @@ our @EXPORT_OK = qw(
                        get_media_info
                );
 
-our $VERSION = '0.03'; # VERSION
-
 our %SPEC;
 
 $SPEC{get_media_info} = {
     v => 1.1,
-    summary => 'Return information on media file/URL',
+    summary => 'Return information on media file/URL, using mplayer',
     args => {
         media => {
             summary => 'Media file/URL',
@@ -80,21 +81,21 @@ sub get_media_info {
 }
 
 1;
-# ABSTRACT: Return information on media file/URL using mplayer
+# ABSTRACT: Return information on media file/URL, using mplayer
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
-Media::Info::Mplayer - Return information on media file/URL using mplayer
+Media::Info::Mplayer - Return information on media file/URL, using mplayer
 
 =head1 VERSION
 
-version 0.03
+This document describes version 0.04 of Media::Info::Mplayer (from Perl distribution Media-Info-Mplayer), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -123,12 +124,16 @@ Sample result:
    },
  ]
 
+=head1 SEE ALSO
+
+L<Media::Info>
+
 =head1 FUNCTIONS
 
 
 =head2 get_media_info(%args) -> [status, msg, result, meta]
 
-Return information on media file/URL.
+{en_US Return information on media file/URL, using mplayer}.
 
 Arguments ('*' denotes required arguments):
 
@@ -136,17 +141,20 @@ Arguments ('*' denotes required arguments):
 
 =item * B<media>* => I<str>
 
-Media file/URL.
+{en_US Media file/URL}.
 
 =back
 
-Return value:
+Returns an enveloped result (an array).
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
 
-=head1 SEE ALSO
-
-L<Media::Info>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -158,8 +166,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Media-Info-Mplayer>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Media-Info-Mplayer
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Media-Info-Mplayer>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -167,11 +174,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
